# Compute constraint shortest path
#
# Ralf Borndoerfer
# 01/2007
# ------------------------------------------------------------------------------
#
# The data are:
# - nodes  contains a list of all OD-nodes, which are a subset of the nodes of
#          the graph. We need this for reading and accessing the OD-matrix.
# - edges  edges of the graph. They are directed and the data should contain
#          forward and backward directions, if wanted.
# - times  edge weights
# - costs  edge costs
# ------------------------------------------------------------------------------
# sets:

# edges (directed!)
set E := { read "edges.dat" as "<1s,2s>" comment "#" };

# nodes
set V := proj(E,<1>) union proj(E,<2>);

# node sets (not needed here)
# set P[] := powerset(V);
# set K   := indexset(P);

# ------------------------------------------------------------------------------
# parameters:

# costs
param c[E] := read "costs.dat" as "<1s,2s> 3n" comment "#";

# travel times
param tt[E] := read "times.dat" as "<1s,2s> 3n" comment "#";

# ------------------------------------------------------------------------------
# Targets:
param s := "Gn";
param t := "Rtd";

# ------------------------------------------------------------------------------
# variables:

# x[u,v] flow on edge <u,v>
var x[<u,v> in E] integer >= 0 <= 1;

# sumc path length
var sumc >= 0;


# ------------------------------------------------------------------------------
# objective: travel time

minimize obj: sum <u,v> in E: tt[u,v]*x[u,v];

# ------------------------------------------------------------------------------
# constraints

subto setc: sum <u,v> in E: c[u,v] * x[u,v] == sumc;

subto length_con: sumc <= 20000;

subto conservation:
	forall <v> in V without {s, t}:
	sum <u,v> in E: x[u,v] - sum <v,u> in E: x[v,u] == 0;

subto out:
	sum <s,v> in E: x[s,v] - sum <v,s> in E: x[v,s] == 1;

       


